@@ -510,11 +510,11 @@ sub must_refresh_files
 
 =head1 COPYRIGHT
 
-2012 Ohio-Pennsylvania Software, LLC.
+L<Bizowie|http://bizowie.com/>
 
 =head1 LICENSE
 
- Copyright (C) 2012 Ohio-Pennsylvania Software, LLC.
+ Copyright (C) 2012, 2013 Bizowie
 
  This file is part of Sysync.
  
